# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .sandbox_config_update_config import SandboxConfigUpdateConfig
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class SandboxConfigUpdate(UncheckedBaseModel):
    """
    Pydantic model for updating SandboxConfig fields.
    """

    config: typing.Optional[SandboxConfigUpdateConfig] = pydantic.Field(default=None)
    """
    The JSON configuration data for the sandbox.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
